package com.ym.mec.web.dal.dao;

import com.ym.mec.common.dal.BaseDAO;
import com.ym.mec.web.dal.dto.TeacherMusicClassInfoDto;
import com.ym.mec.web.dal.dto.TeacherVipClassInfoDto;
import com.ym.mec.web.dal.entity.ClassGroup;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

public interface ClassGroupDao extends BaseDAO<Integer, ClassGroup> {


    /**
     * 查询老师乐团课课程
     *
     * @param teacherId
     * @return
     */
    List<ClassGroup> findClassGroup4Teacher(@Param("teacherId") Integer teacherId);

    /**
     * 获取所有合奏班
     *
     * @return
     */
    List<ClassGroup> findAllMixClassGroup(@Param("musicGroupId") Integer musicGroupId);

    /**
     * 根据合奏班ID查询该合奏班下的子班级
     *
     * @param mixClassGroupId
     * @return
     */
    List<ClassGroup> findMixClassChildClassGroup(@Param("mixClassGroupId") Integer mixClassGroupId);

    /**
     * 根据乐团编号查询单技班级信息
     *
     * @param musicGroupId
     * @return
     */
    List<ClassGroup> findAllNormalClassGroupByMusicGroupId(@Param("musicGroupId") int musicGroupId);

    /**
     * 查询合奏班包含子班的名字信息
     *
     * @param classGroupId
     * @return
     */
    ClassGroup findMixClassChildClassGroupNames(@Param("classGroupId") int classGroupId);

    /**
     * 跟班级ids查询班级信息
     * @param ids
     * @return
     */
    List<ClassGroup> findClassGroupByIds(@Param("ids") String ids);

    /**
     * 根据教师编号获取教师所在乐团，带了哪些班级
     * @param userId
     * @return
     */
    List<TeacherMusicClassInfoDto> queryGroupCourses(Integer userId);

    /**
     * 获取老师VIP课程信息列表
     * @param params
     * @return
     */
    List<TeacherVipClassInfoDto> getTeacherVipClass(Map<String, Object> params);

    /**
     * count老师VIP课程信息列表
     * @param params
     * @return
     */
    int countTeacherVipClass(Map<String, Object> params);
}